@@ -24,7 +24,7 @@ class NotifySerializerV0(serializers.Serializer):
 
 
 class NotifySerializerV1(serializers.Serializer):
-    id = serializers.CharField(read_only=True)
+    id = serializers.CharField(max_length=256)
     type = serializers.CharField(max_length=256)
     created_at = serializers.DateTimeField()
     data = serializers.JSONField()
